API docs for “spamfighter.core.model.bayes.BayesModel”

# Class s.c.m.b.BayesModel(object):

Part of spamfighter.core.model.bayes View Source View In Hierarchy

Модель анализа сообщений по Байесу.

Instance Variables | bayes | анализатор по Байесу (type: `Bayes` )

Method | __init__ | Конструктор.
Method | train | Обучить модель на указанном тексте.
Method | classify | Классифицировать текст согласно модели.

def __init__(self): (source)
Конструктор.

def train(self, text, good): (source)
Обучить модель на указанном тексте.

Parameters | text | текст, на котором обучаемся (type: `unicode` )
| good | хороший это текст или плохой с точки зрения классификации? (type: `bool` )
Returns | результат операции (type: `Deferred` )

def classify(self, text): (source)
Классифицировать текст согласно модели.

Результат классификации - текст "хороший" или "плохой" (относительно модели).

Parameters | text | текст, который классифируем (type: `unicode` )
Returns | результат операции, `bool`, хороший ли текст? (type: `Deferred` )